OiRA

Help

1. Voorbereiding
4. Rapport
5. Status 92%

# Status van Private Security, Grafton Street

## Algemene informatie

Gebruikte tool

  Private Security, Grafton Street

## Certification

### 92% Complete

92% Complete! You've earned a certificate for this tool.

With this certificate, you can apply for a reduction on your company's insurance rates. Learn more about the benefits…

View certificate

## Beantwoorde vragen per module

Commercial manned guarding - Abby Road

  1 question answered without a risk

  3 answers indicated a risk and have at least one measure defined in the action plan

  2 answers indicated a risk without any measure defined in the action plan

  2 questions were postponed

  2 questions aren't answered yet

  - 1 Risico niet aanwezig
  - 3
  - 2 Risico aanwezig
  - 2 Overgeslagen
  - 2 Niet bekekeken

  #### Risico's met een hoge prioriteit

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis
Mobile partrolling/intervention after alarm

  7 Niet bekekeken

  1

  1 Risico aanwezig

  1 Overgeslagen

  - 7 Niet bekekeken
  - 1
  - 1 Risico aanwezig
  - 1 Overgeslagen

  #### High priority risks

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis

Scroll to top
Back

## status-certificate.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More